@@ -353,6 +353,9 @@ class CanFdMessagePy(BlfIoStruct):
         dir_flg_ = self.flags & 0x01
         return self.INDEX_MAP_DIR_STR[dir_flg_]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class CanFdMessage64Py(BlfIoStruct):
     _fields_ =[
         ('channel', ctypes.c_uint8),
@@ -490,6 +493,9 @@ class CanFdMessage64Py(BlfIoStruct):
         dir_ = self.dir & 0x01
         return self.INDEX_MAP_DIR_STR[dir_]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class CanMessagePy(BlfIoStruct):
     _fields_ =[
         ('channel', ctypes.c_uint16),
@@ -553,6 +559,9 @@ class CanMessagePy(BlfIoStruct):
         dir_flag_ = self.flags & 0x01
         return self.INDEX_MAP_DIR_STR[dir_flag_]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class CanMessage2Py(BlfIoStruct):
     _fields_ =[
         ('channel', ctypes.c_uint16),
@@ -635,6 +644,9 @@ class CanMessage2Py(BlfIoStruct):
         dir_flag_ = self.flags & 0x01
         return self.INDEX_MAP_DIR_STR[dir_flag_]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class LinMessagePy(BlfIoStruct):
     _fields_ =[
         ('channel', ctypes.c_uint16),
@@ -731,6 +743,9 @@ class LinMessagePy(BlfIoStruct):
     def DirStr(self) -> str:
         return self.INDEX_MAP_DIR_STR[self.dir]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class LinMessage2Py(BlfIoStruct):
     _fields_ =[
         ('data', ctypes.c_uint8*8),
@@ -846,6 +861,9 @@ class LinMessage2Py(BlfIoStruct):
     def DirStr(self) -> str:
         return self.INDEX_MAP_DIR_STR[self.dir]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class LinFramePy(BlfIoStruct) :
     def __init__(self,
         name: str = '',
@@ -874,6 +892,9 @@ class LinFramePy(BlfIoStruct) :
             'children': self.children,
         })
         return d_
+
+    def GetBlfType(self) -> int:
+        return self._blfObjType
         
 class EthernetFramePy(BlfIoStruct):
     _fields_ =[
@@ -988,6 +1009,9 @@ class EthernetFramePy(BlfIoStruct):
     def DirStr(self) -> str:
         return self.INDEX_MAP_DIR_STR[self.dir]
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class CanISignalIPduPy(BlfIoStruct):
     def __init__(
         self,
@@ -1024,6 +1048,9 @@ class CanISignalIPduPy(BlfIoStruct):
         })
         return d_
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class SomeIpFramePy(BlfIoStruct) :
     INDEX_MAP_DIR_STR = ['tx', 'rx']
     def __init__(
@@ -1116,6 +1143,9 @@ class SomeIpFramePy(BlfIoStruct) :
     def DirStr(self) -> str:
         return self.dir
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 class SomeIpSDFramePy(BlfIoStruct) :
     INDEX_MAP_DIR_STR = ['tx', 'rx']
     def __init__(
@@ -1169,4 +1199,7 @@ class SomeIpSDFramePy(BlfIoStruct) :
     def DirStr(self) -> str:
         return self.dir
 
+    def GetBlfType(self) -> int:
+        return self._blfObjType
+
 
