@@ -3,6 +3,9 @@ import json
 import typing
 from pathlib import Path
 import pymongo
+import traceback
+import orjson
+from bson.objectid import ObjectId
 
 import grpc
 
@@ -11,6 +14,7 @@ from .BlfIo import BlfIoObjs, BlfObjFromBytes
 from .ObjIo import *
 from .Protos import LogReplayNode_pb2, LogReplayNode_pb2_grpc
 from .SharedMemory import IndexNode, SharedMemZoneSender
+from .MongoAPI import MongoAPI
 import platform
 
 
@@ -29,13 +33,21 @@ class LogReplayNodeClient(object):
             self._shareMemReplayData = SharedMemZoneSender(None, name='ZoneSenderReplay')
 
         # mongodb配置
-        self._mongo_client = pymongo.MongoClient(
-            "mongodb://{0}:{1}/".format(
-                ZoneSenderData.MONGO_WIRED_TIGER_HOST,
-                ZoneSenderData.MONGO_WIRED_TIGER_PORT))
-        self._MONGO_DB_NAME = ZoneSenderData.MONGO_DB_NAME
-        self._MONGO_COLLECT_NAME_LOG_REPLAY = ZoneSenderData.MONGO_COLLECT_NAME_LOG_REPLAY
-        self._mongo_collect = self._mongo_client[self._MONGO_DB_NAME][self._MONGO_COLLECT_NAME_LOG_REPLAY]
+        # self._mongo_client = pymongo.MongoClient(
+        #     "mongodb://{0}:{1}/".format(
+        #         ZoneSenderData.MONGO_WIRED_TIGER_HOST,
+        #         ZoneSenderData.MONGO_WIRED_TIGER_PORT))
+        # self._MONGO_DB_NAME = ZoneSenderData.MONGO_DB_NAME
+        # self._MONGO_COLLECT_NAME_LOG_REPLAY = ZoneSenderData.MONGO_COLLECT_NAME_LOG_REPLAY
+        # self._mongo_collect = self._mongo_client[self._MONGO_DB_NAME][self._MONGO_COLLECT_NAME_LOG_REPLAY]
+
+        self.mongo = MongoAPI.MongoAPI(ZoneSenderData.MONGO_WIRED_TIGER_HOST,
+                                       ZoneSenderData.MONGO_WIRED_TIGER_PORT,
+                                       ZoneSenderData.MONGO_DB_NAME,
+                                       ZoneSenderData.MONGO_COLLECT_NAME_LOG_REPLAY
+                                       )
+        self._mongo_collect = self.mongo.mongo_collect
+
 
     def AddLinDecodeRole(
         self,
@@ -300,6 +312,104 @@ class LogReplayNodeClient(object):
             print('LogReplayNodeClient.DbRestore Exception reason {0}'.format(e_))
             return 1000
 
+    def FindLimit(self,
+                 result_l_obj: typing.List[BlfIoObjs.BlfIoStruct],
+                 reslut_l_time_stamp: typing.List[int],
+                 last_id: typing.List[ObjectId],
+                 num: int,
+                  ) -> int:
+        '''
+        :param result_l:list[BlfIoObjs.BlfIoStruct] 解析后的数据 里面会放 BlfIoObjs.CanISignalIPduPy | BlfIoObjs.LinFramePy
+        :return:int
+            - 0:成功
+            - 1:读结束
+        按照升序，读取n条数据
+        '''
+        try:
+            # 如果是相对路径转换为绝对路径
+            result = self.mongo.FindLimit(num)
+
+            result_l_obj.clear()
+            reslut_l_time_stamp.clear()
+            last_id.clear()
+
+            _last_id = None
+            for record in result:
+                e_bytes = (record["blf_obj_type"]).to_bytes(length=1, byteorder='big', signed=False) + orjson.dumps(record["data"])
+                blf_obj_ = BlfObjFromBytes(e_bytes)
+                reslut_l_time_stamp.append(record["time_stamp"])
+                result_l_obj.append(blf_obj_)
+                _last_id = record['_id']
+                print(_last_id)
+            last_id.append(_last_id)
+
+            return 0
+
+        except Exception as e_:
+            _e1 = str(traceback.format_exc())
+            info = "失败：{0}, 详情：{1}".format(e_, _e1)
+            print('LogReplayNodeClient.FindLimit Exception reason {0}'.format(info))
+            return 1000
+
+    def FindByPaging(self,
+                  result_l_obj: typing.List[BlfIoObjs.BlfIoStruct],
+                  reslut_l_time_stamp: typing.List[int],
+                  last_id: typing.List[ObjectId],
+                  rid: ObjectId,
+                  span: int,
+                  ) -> int:
+        '''
+        :param result_l:list[BlfIoObjs.BlfIoStruct] 解析后的数据 里面会放 BlfIoObjs.CanISignalIPduPy | BlfIoObjs.LinFramePy
+        :return:int
+            - 0:成功
+            - 1:读结束
+        分页读取n条数据
+        '''
+        try:
+            # 如果是相对路径转换为绝对路径
+            result = self.mongo.FindByPaging(rid, span)
+
+            result_l_obj.clear()
+            reslut_l_time_stamp.clear()
+            last_id.clear()
+
+            _last_id = None
+            for record in result:
+                e_bytes = (record["blf_obj_type"]).to_bytes(length=1, byteorder='big', signed=False) + orjson.dumps(record["data"])
+                blf_obj_ = BlfObjFromBytes(e_bytes)
+                reslut_l_time_stamp.append(record["time_stamp"])
+                result_l_obj.append(blf_obj_)
+                _last_id = record['_id']
+                print(_last_id)
+
+            last_id.append(_last_id)
+
+            return 0
+
+        except Exception as e_:
+            _e1 = str(traceback.format_exc())
+            info = "失败：{0}, 详情：{1}".format(e_, _e1)
+            print('LogReplayNodeClient.FindLimit Exception reason {0}'.format(info))
+            return 1000
+
+
+    def GetCount(self) -> int:
+        '''
+        打开回放的文件
+        :param blf_file_path:str 要打开的文件路径
+        :return:int
+            - 0:成功
+            - other:失
+        '''
+
+        try:
+            # 如果是相对路径转换为绝对路径
+            res = self.mongo.GetCount()
+            return res
+        except Exception as e_:
+            print('LogReplayNodeClient.DbRestore Exception reason {0}'.format(e_))
+            return 1000
+
     def OpenReplayFile(self, blf_file_path: str) -> int:
         '''
         打开回放的文件
