@@ -10,7 +10,7 @@ class CanStackConfig(ZoneSenderObject):
         bitrate: 'int' = 500000,
         fd_bitrate: 'int' = 2000000,
         bus_type: 'str' = 'vector',
-        app_name: 'str' = 'ZoneSender') -> None:
+        app_name: 'str' = 'ZoneSender_can') -> None:
         super().__init__()
         self.channel = channel
         self.isFd = is_fd
