@@ -19,6 +19,7 @@ class SomeipPackage(ZoneSenderObject):
         interface_name: 'str' = '',
         interface_type: 'str' = '',
         context: 'dict' = {},
+        channel: int = 1,
         *args, **kwargs) -> None:
         #########################
         super().__init__()
@@ -36,6 +37,7 @@ class SomeipPackage(ZoneSenderObject):
         self.payload = kwargs.get('payload', bytes())
         self.msgType = 0
         self.session_id = 0
+        self.channel = channel
     
     def __str__(self) -> str:
         # return super().__str__()
@@ -55,6 +57,7 @@ interfaceName: {9}
 context: {10}
 msgtype:{11}
 session_id:{12}
+channel:{13}
         '''.format(
             self.srcIp,
             self.srcPort,
@@ -69,6 +72,7 @@ session_id:{12}
             self.context,
             self.msgType,
             self.session_id,
+            self.channel,
         )
 
     @staticmethod
@@ -91,6 +95,7 @@ session_id:{12}
             someip_package_.payload = obj.get('payload', bytes())
             someip_package_.msgType = obj['msg_type']
             someip_package_.session_id = obj['session_id']
+            someip_package_.channel = obj.get('channel', 1)
             return someip_package_
         raise TypeError
 
@@ -110,6 +115,7 @@ session_id:{12}
             'payload': self.payload,
             'msgType': self.msgType,
             'session_id':self.session_id,
+            'channel':self.channel,
         }
 
     @staticmethod
@@ -127,4 +133,5 @@ session_id:{12}
         someip_dist.interfaceId = someip_src.interfaceId
         someip_dist.interfaceName = someip_src.interfaceName
         someip_dist.context = someip_src.context
-        someip_dist.payload = someip_src.payload
\ No newline at end of file
+        someip_dist.payload = someip_src.payload
+        someip_dist.channel = someip_src.channel
\ No newline at end of file
