@@ -1,8 +1,10 @@
 import threading
 
 class TestAssist(object):
+    TA_TEXT_EVENT_DICT = dict()
+    
     def __init__(self) -> None:
-        self.TA_TEXT_EVENT_DICT = dict()
+        pass
 
     def TA_WaitForTextEvent(self, text: 'str', time_out_ms: 'int') -> 'int':
         ''' 等待字符串, 如果在规定时间等不到就 pass
@@ -14,9 +16,9 @@ class TestAssist(object):
             - 1 超时, 在规定的时间没有等到期望的字符串\n
             - 2 线程拿不到 Event 对象\n
         '''
-        if (text not in self.TA_TEXT_EVENT_DICT.keys()):
-            self.TA_TEXT_EVENT_DICT[text] = threading.Event()
-        event_ = self.TA_TEXT_EVENT_DICT[text]
+        if (text not in TestAssist.TA_TEXT_EVENT_DICT.keys()):
+            TestAssist.TA_TEXT_EVENT_DICT[text] = threading.Event()
+        event_ = TestAssist.TA_TEXT_EVENT_DICT[text]
         if (not isinstance(event_, threading.Event)):
             return 2
         event_.clear()
@@ -29,9 +31,9 @@ class TestAssist(object):
 
         :param text: str 要触发的字符串，触发后会让所有的等待字符串事件通过
         '''
-        if (text not in self.TA_TEXT_EVENT_DICT.keys()):
+        if (text not in TestAssist.TA_TEXT_EVENT_DICT.keys()):
             return
-        event_ = self.TA_TEXT_EVENT_DICT[text]
+        event_ = TestAssist.TA_TEXT_EVENT_DICT[text]
         if (not isinstance(event_, threading.Event)):
             return
         event_.set()
\ No newline at end of file
