@@ -11,6 +11,7 @@ from .LogReplayNodeClient import LogReplayNodeClient
 from .CanUdsNodeClient import CanUdsNodeClient
 from .TcpIpNodeClient import TcpIpNodeClient
 from .ConfigNodeClient import ConfigNodeClient
+from .DoIPUdsNodeClient import DoIPUdsNodeClient
 
 
 class ZoneSenderFramework(object):
@@ -33,6 +34,7 @@ class ZoneSenderFramework(object):
         self.CanUds = CanUdsNodeClient()
         self.TcpIpStack = TcpIpNodeClient()
         self.Config = ConfigNodeClient()
+        self.DoIPUds = DoIPUdsNodeClient()
 
 
     def Reset(self) -> None:
@@ -56,6 +58,7 @@ class ZoneSenderFramework(object):
         self.LinStack.reset()
         self.LinParser.clearChannelConfig()
         self.LinParser.clearSubscribe()
+        self.DoIPUds.reset()
 
     def Reset_LIN(self) ->None :
         ''' 复位所有功能，包括:\n
