@@ -1,5 +1,6 @@
 import json
 import os
+import platform
 import time
 import typing
 import uuid
@@ -8,14 +9,11 @@ from concurrent.futures import ThreadPoolExecutor
 import grpc
 import paho.mqtt.client as mqtt
 
-
-
 from . import ZoneSenderData
-
 from .ObjIo import *
-from .ZoneSenderFramework import ZoneSenderFramework
 from .SharedMemory import SharedMemZoneSender
-import platform
+# from .ObjIo import 
+from .ZoneSenderFramework import ZoneSenderFramework
 
 
 class ZoneSenderStone(ZoneSenderFramework):
@@ -98,12 +96,14 @@ class ZoneSenderStone(ZoneSenderFramework):
             self._mqttClient.subscribe('zonesender/someipnode/someippackage/{0}'.format(obj_.serviceName))
             self._mqttClient.subscribe('zonesender/someipnode/someipcalling/{0}'.format(obj_.serviceName))
             self._mqttClient.subscribe('zonesender/someipnode/someipbypass/{0}'.format(obj_.serviceName))
+            payload_ = json.dumps({
+                    'client_id': self._mqttClient._client_id.decode('utf-8'),
+                    'service_name': obj_.serviceName,
+                    'channel': obj_.channel,
+                }).encode('utf-8')
             self._mqttClient.publish(
                 topic='zonesender/someipnode/subscribe',
-                payload=json.dumps({
-                    'client_id': self._mqttClient._client_id.decode('utf-8'),
-                    'service_name': obj_.serviceName
-                }).encode('utf-8')
+                payload=payload_
             )
         elif isinstance(obj_,LinFrame):
             self._mqttClient.subscribe('zonesender/linparsernode/frame/{0}/{1}'.format(obj_.channel, obj_.name))
@@ -139,7 +139,6 @@ class ZoneSenderStone(ZoneSenderFramework):
                 }).encode('utf-8')
             )
         elif isinstance(obj_, DiagnosticEcuInfo):
-            print("DiagnosticEcuInfo")
             self._mqttClient.subscribe('zonesender/canudsnode/Rx/diagnostic_request')
             self._mqttClient.subscribe('zonesender/canudsnode/Rx/diagnostic_response')
             self._mqttClient.publish(
@@ -156,7 +155,6 @@ class ZoneSenderStone(ZoneSenderFramework):
                 )
             )
         elif isinstance(obj_, DiagnosticEcuInfo_DoIP):
-            print("DiagnosticEcuInfo_DoIP unsubscribe")
             self._mqttClient.subscribe('zonesender/doipudsnode/Rx/diagnostic_request')
             self._mqttClient.subscribe('zonesender/doipudsnode/Rx/diagnostic_response')
             self._mqttClient.publish(
@@ -232,7 +230,8 @@ class ZoneSenderStone(ZoneSenderFramework):
                 topic='zonesender/someipnode/unsubscribe',
                 payload=json.dumps({
                     'client_id': self._mqttClient._client_id.decode('utf-8'),
-                    'service_name':obj_.serviceName
+                    'service_name':obj_.serviceName,
+                    'channel': obj_.channel,
                 }).encode('utf-8')
             )
         elif (isinstance(obj_, LinFrame)):
@@ -269,7 +268,6 @@ class ZoneSenderStone(ZoneSenderFramework):
                 }).encode('utf-8')
             )
         elif isinstance(obj_, DiagnosticEcuInfo):
-            print("DiagnosticEcuInfo unsubscribe")
             self._mqttClient.unsubscribe('zonesender/canudsnode/Rx/diagnostic_request')
             self._mqttClient.unsubscribe('zonesender/canudsnode/Rx/diagnostic_response')
             self._mqttClient.publish(
@@ -286,7 +284,6 @@ class ZoneSenderStone(ZoneSenderFramework):
                 )
             )
         elif isinstance(obj_, DiagnosticEcuInfo_DoIP):
-            print("DiagnosticEcuInfo_DoIP unsubscribe")
             self._mqttClient.unsubscribe('zonesender/doipudsnode/Rx/diagnostic_request')
             self._mqttClient.unsubscribe('zonesender/doipudsnode/Rx/diagnostic_response')
             self._mqttClient.publish(
@@ -378,7 +375,7 @@ class ZoneSenderStone(ZoneSenderFramework):
         '''
         pass
 
-    def OnSomeipCalling(self, timestamp, someip_in: SomeipPackage, someip_out: SomeipPackage, is_response:bool = True) -> None:
+    def OnSomeipCalling(self, timestamp, someip_in: SomeipPackage, someip_out: SomeipPackage) -> None:
         ''' [需要用户重写实现定制功能]\n
         作为 Provider 端调用，当收到 Someip Consumer 的请求做什么\n
         根据 someip_in 的数据做逻辑判断，给 someip_out.context 赋值实现自定义返回数据\n
@@ -559,7 +556,7 @@ class ZoneSenderStone(ZoneSenderFramework):
                 payload=json.dumps(d_).encode('utf-8')
             )
         except Exception as e_:
-            print(e_)
+            print('ZoneSenderStone.SomeipCallAsync Exception {0}'.format(e_))
 
     def SomeipSetDefaultAnswer(self, someip_package: 'SomeipPackage') -> None:
         ''' 作为 Server 调用，设置后台 SomeIpServer 的数据
@@ -573,14 +570,15 @@ class ZoneSenderStone(ZoneSenderFramework):
                 'ince_id': someip_package.instanceId,
                 'if_name': someip_package.interfaceName,
                 'if_type': someip_package.interfaceType,
-                'context': someip_package.context
+                'context': someip_package.context,
+                'channel': someip_package.channel,
             }
             self._mqttClient.publish(
                 topic='zonesender/someipnode/request/setvalue',
-                payload=json.dumps(d_).encode('utf-8')
+                payload=json.dumps(d_).encode('utf-8'),
             )
         except Exception as e_:
-            print(e_)
+            print('ZoneSenderStone.SomeipSetDefaultAnswer Exception {0}'.format(e_))
 
     def SomeipPublish(self, someip_package: 'SomeipPackage', *args, **kwargs) -> None:
         ''' 作为 Server 调用，发送一次 Notification 或者 Event
@@ -598,7 +596,7 @@ class ZoneSenderStone(ZoneSenderFramework):
                 payload=json.dumps(d_).encode('utf-8')
             )
         except Exception as e_:
-            print(e_)
+            print('ZoneSenderStone.SomeipPublish Exception {0}'.format(e_))
     
     def SetLinData(self,obj) :
         '''设置LIN报文, 数据将立刻发送
@@ -916,7 +914,7 @@ class ZoneSenderStone(ZoneSenderFramework):
         '''
         someip_in_ = SomeipPackage.From(recv_d)
         someip_out_ = SomeipPackage.From(recv_d)
-        # someip_out_.context = {}
+        someip_out_.context = {}
         self.OnSomeipCalling(recv_d['t'], someip_in_, someip_out_)
         
         self.SomeipSetDefaultAnswer(someip_out_)
